use std::sync::Arc;

use axum::extract::State;
use maud::{html, Markup, DOCTYPE};

use crate::{
    clock,
    data::{self, CombinedFish},
    AppState,
};

pub fn layout(content: Markup) -> Markup {
    html! {
        (DOCTYPE)
        html {
            head {
                title { "beacon" }
                meta name="viewport" content="width=device-width";
                link rel="stylesheet" href="/static/style.css";
            }

            body { (content) }
        }
    }
}

pub fn main_page(state: State<Arc<AppState>>) -> Markup {
    let meta = state.data.fish_with_meta();
    let mut values: Vec<&CombinedFish> = meta.values().filter(|f| f.entry.big_fish).collect();
    values.sort_by(|afish, bfish| bfish.is_up.cmp(&afish.is_up));
    layout(html! {
        h1 { "Hello! Current ET: " (clock::get_current_eorzea_date().format("%H:%M")) }
        @for fish in values {
            section.up[fish.is_up] {
                .title {
                    h3 { (fish.meta.name_en) }
                }
                .meta {
                    @if fish.entry.start_hour.is_some() && fish.entry.end_hour.is_some() {
                        div {
                            (clock::display_eorzea_time(&clock::set_hm_from_float(&clock::get_current_eorzea_date(), fish.entry.start_hour.unwrap())))
                            " to "
                            (clock::display_eorzea_time(&clock::set_hm_from_float(&clock::get_current_eorzea_date(), fish.entry.end_hour.unwrap())))
                        }
                    }
                }
            }
        }
    })
}
